@@ -9,18 +9,18 @@ Michael Hucka <mhucka@caltech.edu> -- Caltech Library
 Copyright
 ---------
 
-Copyright (c) 2018-2020 by the California Institute of Technology.  This code
+Copyright (c) 2018-2021 by the California Institute of Technology.  This code
 is open-source software released under a 3-clause BSD license.  Please see the
 file "LICENSE" for more information.
 '''
 
-from appdirs import user_config_dir
+from   appdirs import user_config_dir
+from   commonpy.file_utils import copy_file
 import os
-from   os import path
+from   os import path, makedirs
 from   sidetrack import log
 
 import handprint
-from handprint.files import make_dir, copy_file
 
 from .credentials_files import credentials_filename
 
@@ -48,6 +48,6 @@ class Credentials(object):
     def save_credentials(self, service, supplied_file):
         if not path.isdir(Credentials.creds_dir):
             if __debug__: log('creating credentials dir: {}.', Credentials.creds_dir)
-            make_dir(Credentials.creds_dir)
+            makedirs(Credentials.creds_dir)
         dest_file = path.join(Credentials.creds_dir, credentials_filename(service))
         copy_file(supplied_file, dest_file)
