@@ -20,14 +20,10 @@ import io
 import json
 import math
 import os
-import google
-from google.cloud import vision_v1 as gv
-from google.api_core.exceptions import PermissionDenied
-from google.protobuf.json_format import MessageToDict
 import json
 
 if __debug__:
-    from sidetrack import set_debug, log, logr
+    from sidetrack import log
 
 import handprint
 from handprint.credentials.google_auth import GoogleCredentials
@@ -109,6 +105,13 @@ class GoogleTR(TextRecognition):
         The result is returned as an TRResult named tuple.
         '''
 
+        # Delay loading the API packages until needed because they take time to
+        # load.  Doing this speeds up overall application start time.
+        import google
+        from google.cloud import vision_v1 as gv
+        from google.api_core.exceptions import PermissionDenied
+        from google.protobuf.json_format import MessageToDict
+
         if not result:
             # Read the image and proceed with contacting the service.
             (image, error) = self._image_from_file(path)
@@ -206,6 +209,7 @@ def corner_list(vertices):
 # https://github.com/googleapis/python-memcache/issues/19#issuecomment-709628506
 
 def dict_from_response(response):
+    import google
     if isinstance(response, google.cloud.vision_v1.types.image_annotator.AnnotateImageResponse):
         return response.__class__.to_dict(response)
     else:
